

Configuration for wanderlus

The configuration is spread into three files:
 - One part in the .emacs file (or a file loaded in the .emacs file)
 - Most of the configuration is in the .wl file -> Emacs only read this file
   when wanderlust is loaded
 - The folders definitions is in the .folders file

* Configuration in my .emacs file

#+begin_src lisp
  ;; Tell Emacs my E-Mail address
  ;; Without this Emacs thinks my E-Mail is something like <myname>@ubuntu-asus
  (setq user-mail-address "<user>@gmail.com")
  
  ;; Uncomment the line below if you have problems with accented letters
  ;; (setq-default mime-transfer-level 8) ;; default value is 7
  
  (autoload 'wl "wl" "Wanderlust" t)
  (autoload 'wl-other-frame "wl" "Wanderlust on new frame." t)
  (autoload 'wl-draft "wl-draft" "Write draft with Wanderlust." t)
  
  ;; Most of the configuration for wanderlust is in the .wl file. The line below
  ;; makes sure it will be opened with emacs-lisp-mode
  (add-to-list 'auto-mode-alist '("\.wl$" . emacs-lisp-mode))
#+end_src

* Configuration in the .wl file

#+begin_src lisp
  (setq wl-insert-message-id nil) ; let the SMTP servers handle the message-id and stop warning from wanderlust
  
  ;; I don't know why I need this
  (setq elmo-imap4-use-modified-utf7 t)
  
  
  ;; xxxxxxxxxxxxxxx Set the templates xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  (setq wl-template-alist
  '(
    ("gmail"                            ; Gmail
     (wl-from . "MY FULL NAME <USERNAME@gmail.com>")
     ("From" . wl-from)
     (wl-smtp-connection-type . 'starttls)
     (wl-smtp-posting-port . 587)
     (wl-smtp-authenticate-type . "plain")
     (wl-smtp-posting-user . "USERNAME")
     (wl-smtp-posting-server . "smtp.gmail.com")
     (wl-local-domain . "gmail.com")
     (signature-file-name . "~/.signature")
     )
    ("Work"
     (wl-from . "MY FULL NAME <USERNAME@work.something>")
     ("From" . wl-from)
     (wl-smtp-connection-type . nil)
     (wl-smtp-posting-port . nil)
     (wl-smtp-authenticate-type . "login") ; change if necessary
     (wl-smtp-posting-user . "USERNAME")
     (wl-smtp-posting-server . "smtp.work.something")
     (wl-local-domain . "work.something")
     ("Organization" . "COMPANY NAME")
     (signature-file-name . "~/.signature_work")
     )
    ("Work-From-Home"
     (wl-from . "MY FULL NAME <USERNAME@work.something>")
     ("From" . wl-from)
     (wl-smtp-connection-type . nil)
     (wl-smtp-posting-port . 9025) ; I need to open an ssh tunnel to redirect this port in my local computer to port 25 in my work
     (wl-smtp-authenticate-type . "login")
     (wl-smtp-posting-user . "USERNAME")
     (wl-smtp-posting-server . "localhost")
     (wl-local-domain . "work.something")
     ("Organization" . "COMPANY NAME")
     (signature-file-name . "~/.signature_work")
     )
    ))
  ;; xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  
  
  ;; xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  ;; Automatically select the correct template based on which folder I'm visiting
  (setq wl-draft-config-matchone t) ;; If non-nil, applied only one element of `wl-draft-config-alist'.
  (setq wl-draft-config-alist
        '(
          ( ; If I start a draft from my work e-mail folder and I'm using my
            ; personal computer (from home) use the template "Work-From-Home". I
            ; use a two different templates for my work E-Mail because I don't
            ; have access to the smtp server of my work when I'm at home. But
            ; since I can ssh to it i redirect a port to be able to sent e-mail
            ; from home though the smtp server of my work
           (and (string-match ".*work" wl-draft-parent-folder) (string-match "laptop" system-name))
           (template . "Work-From-Home")
           )
          ( ; If I start a draft from my work e-mail folder and I'm using my
            ; work computer, use the "Work" template
           (and (string-match ".*work" wl-draft-parent-folder) (string-match "work-computer" system-name))
           (template . "Work")
           )
          ( ;; If I start a draft from any other folder, use the "gmail" template.
           (not (string-match ".*work" wl-draft-parent-folder))
           (template . "gmail")
           )
          ))
  
  ;; Apply wl-draft-config-alist as soon as you enter in a draft buffer. Without
  ;; this wanderlust would apply it only when actually sending the e-mail.
  (add-hook 'wl-mail-setup-hook 'wl-draft-config-exec)
  ;; xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  
  
  ;; If you want to manually change the template use C-c C-j in a draft buffer
  ;; (wl-template-select). The four lines below allow changint the template with
  ;; the arrow keys
  (define-key wl-template-mode-map (kbd "<right>") 'wl-template-next)
  (define-key wl-template-mode-map (kbd "<left>") 'wl-template-prev)
  (define-key wl-template-mode-map (kbd "<up>") 'wl-template-next)
  (define-key wl-template-mode-map (kbd "<down>") 'wl-template-prev)
  
  
  
  (autoload 'wl-user-agent-compose "wl-draft" nil t)
  (if (boundp 'mail-user-agent)
      (setq mail-user-agent 'wl-user-agent))
  (if (fboundp 'define-mail-user-agent)
      (define-mail-user-agent
        'wl-user-agent
        'wl-user-agent-compose
        'wl-draft-send
        'wl-draft-kill
        'mail-send-hook))
  
  
  ;; xxxxxxxxxxxxxxx General configurations xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  (setq
    wl-forward-subject-prefix "Fwd: " )    ;; use "Fwd: " not "Forward: "
  
  ;; You should set this variable if you use multiple e-mail addresses.
  (setq wl-user-mail-address-list (quote ("USERNAME@work.something" "USERNAME@gmail.com")))
  
  ;; Setting as "t" means that wanderlust should use a new frame for the draft
  (setq wl-draft-use-frame t)
  
  ;; Proportion of the summary and message windows
  (setq wl-message-window-size '(3 . 7))
  
  ;; Fields in the e-mail header that I do not want to see (regexps)
  (setq wl-message-ignored-field-list (quote (".*Received:" ".*Path:" ".*Id:" "^References:" "^Replied:" "^Errors-To:" "^Lines:" "^Sender:" ".*Host:" "^Xref:" "^Content-Type:" "^Precedence:" "^Status:" "^X-VM-.*:" "^List-*" "^Authentication-Results*" "^X-*" "^Received-SPF*" "^DKIM-Signature:" "^DomainKey-Signature:" "^X-Mailman-Version:")))
  ;; Fields in the e-mail header that I want to see even if they match the regex in wl-message-ignored-field-list
  (setq wl-message-visible-field-list (quote ("^Dnas.*:" "^Message-Id:" "^X-Mailer:" "^X-Mailman-Version:")))
  
  ;; Enables auto-fill-mode in the draft buffer
  (add-hook 'wl-mail-setup-hook 'auto-fill-mode)
  
  
  ;; Use orgstruct++-mode in the draft buffer
  ;; (add-hook 'mail-mode-hook 'turn-on-orgstruct)
  (add-hook 'mail-mode-hook 'turn-on-orgstruct++)
  
  
  ;; Set the key "f" to browse-url when I'm reading an E-mail. If instead of an url I have an HTML code I can simple select the code and hit "F"
  (add-hook 'mime-view-mode-hook
            (lambda ()
              (local-set-key "f" 'browse-url)
              (local-set-key "F" 'browse-url-of-region)))
  ;; xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  
  
  
  ;; Auto-refile With this wanderlust suggests folders to refile a message when I
  ;; press the "o" in the summary. Then I can simple press ENTER to accept or
  ;; write (with TAB completion) the folder I want to refile the message For
  ;; instance, if I want wanderlus to suggest the gmail trash folder when I refile
  ;; an E-mail from launchpad about a bug or an E-mail from the org-mode list I
  ;; may use
  (setq wl-refile-rule-alist '(
                               ("To" ("emacs-orgmode@gnu.org" . "%[Gmail]/Lixeira:\"USERNAME@gmail.com\"/clear@imap.gmail.com:993!"))
                               ("Subject" ("\\[Bug [0-9]*\\]" . "%[Gmail]/Lixeira:\"USERNAME@gmail.com\"/clear@imap.gmail.com:993!")) ; E-Mails do Launchpad
                               )) ; Notice that the folders must match what I have used in the .folders file
  
  
  ;; xxxxxxxxxxxxxxx Integration with bbdb xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  (require 'bbdb-wl)
  (bbdb-wl-setup)
  
  (setq bbdb-use-pop-up nil ;; disable pop-ups
        ;; bbdb-pop-up-target-lines 5   ; only useful if pop-ups are enabled
        )
  
  ;; Set bbdb-user-mail-names with a regex that matches both of my e-mail accounts
  ;; Pra que serve bbdb-user-mail-names?
  (setq bbdb-user-mail-names (regexp-opt '("USERNAME@gmail.com" "USERNAME@work.something")))
  
  ;; auto collection
  (setq bbdb/mail-auto-create-p 'prompt) ;; bbdb asks me if I want to save an E-mail
  
  ;; exceptional folders against auto collection. The regex must match all folders that we do not want auto-colection. This is what I use
  (setq bbdb-wl-ignore-folder-regexp "^@\\|Org-Mode\\|Muse\\|Doxygen\\|Launchpad")
  
  
  (setq bbdb-north-american-phone-numbers-p nil)
  
  
  ;; shows the name of bbdb in the summary. Default value of this variable is
  ;; wl-summary-default-from which does not use bbdb, but the wanderlust address
  ;; book instead
  (setq wl-summary-from-function 'bbdb-wl-from-func)
  
  
  ;; Using BBDB for pet names in wanderlust
  (setq wl-summary-get-petname-function 'bbdb-wl-get-petname)
  
  
  ;; You can complete address with BBDB by `M-TAB' in draft buffer.
  ;; xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  
  
  ;; xxxxxxxxxxxxxxx Spam check xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  (setq elmo-spam-scheme 'bogofilter) ;; sa for spamassassin, see the elmo-spam-scheme
                                      ;; docs for alternatives
  (require 'wl-spam)
  (setq wl-spam-folder "spam folder as defined in the .folders file")
  
  ;; Automatically check for spam in the folders that match the regex
  (setq wl-spam-auto-check-folder-regexp-list '("regex here"))
  
  
  ;; Folders that should not be checked for spam. Since gmail already has spam checking I make the regex match it
  (setq wl-spam-ignored-folder-regexp-list
        (list (regexp-opt (list wl-draft-folder
                                wl-trash-folder
                                wl-queue-folder
                                "my_gmail_username"
                                "Gmail"
                                "gmail"))))
  ;; xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
#+end_src

* Configuration of the .folders file

#+begin_example
  +trash    "Trash"
  +draft  "Drafts"
  WORK{
      %inbox:USERNAME/clear@imap.work.something:143    "Caixa de Entrada"
      %inbox.Archived:USERNAME/clear@imap.work.something:143    "Archived"
      %inbox.Junk:USERNAME/clear@imap.work.something:143   "Spam"
      %inbox.Sent:USERNAME/clear@imap.work.something:143   "Sent"
      %inbox.Trash:USERNAME/clear@imap.work.something:143  "Trash"
  }
  
  Gmail{
      %inbox:"USERNAME@gmail.com"/clear@imap.gmail.com:993! "Inbox"
      Labels{
          %[Gmail]/Trash:"USERNAME@gmail.com"/clear@imap.gmail.com:993! "Trash"
          %[Gmail]/Star:"USERNAME@gmail.com"/clear@imap.gmail.com:993! "With a Star"
          %[Gmail]/Sent:"USERNAME@gmail.com"/clear@imap.gmail.com:993! "Sent"
          %[Gmail]/Draft:"USERNAME@gmail.com"/clear@imap.gmail.com:993! "Draft"
      %[Gmail]/All E-Mails:"USERNAME@gmail.com"/clear@imap.gmail.com:993! "All E-Mails"
      }
      %Org-Mode:"USERNAME@gmail.com"/clear@imap.gmail.com:993! "Org-Mode"
  }
#+end_example

